[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/funcx-faas/funcx-common/main.svg)](https://results.pre-commit.ci/latest/github/funcx-faas/funcx-common/main)

# globus-compute-common

This package contains common utilities for use across various Globus Compute projects.

For example, constants shared between the Globus Compute Web Service and the SDK are
defined here (and may be re-exported by the SDK).
